==> qtjambi-nfc-debuginfo-macos-5.15.20.jar: sources/QtJambiNfc/QNearFieldTarget_shell.h <==
#ifndef QNEARFIELDTARGET_SHELL_H
#define QNEARFIELDTARGET_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtNfc/qnearfieldtarget.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtNfc/qndefmessage.h>
#include <QtJambi/RegistryAPI>


class QNearFieldTarget_shell : public QNearFieldTarget, public QtJambiShellInterface
{
public:
    QNearFieldTarget_shell(QObject* parent0 = nullptr);
    ~QNearFieldTarget_shell() override;

    QNearFieldTarget::AccessMethods accessMethods() const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool handleResponse(const QNearFieldTarget::RequestId& id0, const QByteArray& response1) override;
    bool hasNdefMessage() override;
    QNearFieldTarget::RequestId readNdefMessages() override;
    QNearFieldTarget::RequestId sendCommand(const QByteArray& command0) override;
    QNearFieldTarget::RequestId sendCommands(const QList<QByteArray>& commands0) override;
    void timerEvent(QTimerEvent* event0) override;
    QNearFieldTarget::Type type() const override;
    QByteArray uid() const override;
    QUrl url() const override;
    bool waitForRequestCompleted(const QNearFieldTarget::RequestId& id0, int msecs1) override;
    QNearFieldTarget::RequestId writeNdefMessages(const QList<QNdefMessage>& messages0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QNearFieldTarget_access : public QNearFieldTarget
{
    void __qt_reportError_QNearFieldTarget_Error_cref_QNearFieldTarget_RequestId(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint error0, QtJambiNativeID id1);
    jint __qt_accessMethods_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_handleResponse_cref_QNearFieldTarget_RequestId_cref_QByteArray(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID id0, QtJambiNativeID response1);
    jboolean __qt_hasNdefMessage(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_readNdefMessages(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_sendCommand_cref_QByteArray(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID command0);
    jobject __qt_sendCommands_cref_QList(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject commands0);
    jint __qt_type_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_uid_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_url_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_waitForRequestCompleted_cref_QNearFieldTarget_RequestId_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID id0, jint msecs1);
    jobject __qt_writeNdefMessages_cref_QList(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject messages0);
};

#endif // QNEARFIELDTARGET_SHELL_H

==> qtjambi-nfc-debuginfo-macos-6.5.4.jar: sources/QtJambiNfc/QNearFieldTarget_shell.h <==
#ifndef QNEARFIELDTARGET_SHELL_H
#define QNEARFIELDTARGET_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtNfc/qnearfieldtarget.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtNfc/qndefmessage.h>
#include <QtJambi/RegistryAPI>


class QNearFieldTarget_shell : public QNearFieldTarget, public QtJambiShellInterface
{
public:
    QNearFieldTarget_shell(QObject* parent0 = nullptr);
    ~QNearFieldTarget_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QNearFieldTarget_access : public QNearFieldTarget
{
};

#endif // QNEARFIELDTARGET_SHELL_H
